pub struct PutKvBlocksBatchResp {
pub total_bytes: u64,
pub error: Option<String>,
}Expand description
Response payload for op::PUT_KV_BLOCKS_BATCH.
total_bytes is the sum of all payloads[i].len() on success.
error is Some(msg) if any per-block PUT failed; in that case the
metadata index is left unchanged for the failed batch (server-side
transaction: index updates only run after ALL per-block PUTs succeed).
Fields
total_bytes: u64error: Option<String>Trait Implementations
Sourceimpl Archive for PutKvBlocksBatchResp
impl Archive for PutKvBlocksBatchResp
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
serialize. Read moreSourcetype Archived = ArchivedPutKvBlocksBatchResp
type Archived = ArchivedPutKvBlocksBatchResp
Sourcetype Resolver = PutKvBlocksBatchRespResolver
type Resolver = PutKvBlocksBatchRespResolver
Sourceimpl Clone for PutKvBlocksBatchResp
impl Clone for PutKvBlocksBatchResp
Sourcefn clone(&self) -> PutKvBlocksBatchResp
fn clone(&self) -> PutKvBlocksBatchResp
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for PutKvBlocksBatchResp
impl Debug for PutKvBlocksBatchResp
Sourceimpl<__D: Fallible + ?Sized> Deserialize<PutKvBlocksBatchResp, __D> for Archived<PutKvBlocksBatchResp>
impl<__D: Fallible + ?Sized> Deserialize<PutKvBlocksBatchResp, __D> for Archived<PutKvBlocksBatchResp>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<PutKvBlocksBatchResp, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<PutKvBlocksBatchResp, <__D as Fallible>::Error>
Sourceimpl PartialEq for PutKvBlocksBatchResp
impl PartialEq for PutKvBlocksBatchResp
Sourcefn eq(&self, other: &PutKvBlocksBatchResp) -> bool
fn eq(&self, other: &PutKvBlocksBatchResp) -> bool
self and other values to be equal, and is used by ==.impl Eq for PutKvBlocksBatchResp
impl StructuralPartialEq for PutKvBlocksBatchResp